import React from 'react'
import PropTypes from 'prop-types'
import styled, { css, keyframes } from 'styled-components'

const rotate360 = keyframes`
  from {
    transform: rotate(0deg);
  }

  to {
    transform: rotate(360deg);
  }
`

const Spinner = styled.div`
  position: absolute;
  display: block;
  width: ${props => `${props.size}px`};
  height: ${props => `${props.size}px`};
  border-radius: 50%;
  box-shadow: ${props =>
    props.layer1
      ? props.layer1
      : `0px ${props.thickness}px ${props.thickness}px ${
          props.spread
        }px indianred`};
  ${props => props.animation1}

  &:before {
    position: absolute;
    content: '';
    border-radius: 50%;
    top: ${props => `${props.outerOffset}px`}
    right: ${props => `${props.outerOffset}px`}
    bottom: ${props => `${props.outerOffset}px`}
    left: ${props => `${props.outerOffset}px`}
    box-shadow: ${props =>
      props.layer2
        ? props.layer2
        : `0px ${props.thickness}px ${props.thickness}px ${
            props.spread
          }px gold`};
    ${props => props.animation2}
  }

  &:after {
    position: absolute;
    content: '';
    top: ${props => `${props.innerOffset}px`}
    right: ${props => `${props.innerOffset}px`}
    bottom: ${props => `${props.innerOffset}px`}
    left: ${props => `${props.innerOffset}px`}
    border-radius: 50%;
    box-shadow: ${props =>
      props.layer3
        ? props.layer3
        : `0px ${props.thickness}px ${props.thickness}px ${
            props.spread
          }px cornflowerblue`};
    ${props => props.animation3}
  }
`

export default function Spinner3(props) {
  return <Spinner style={props.style} {...props} />
}

Spinner3.defaultProps = {
  size: 150,
  spread: 0,
  thickness: 1,
  innerOffset: 10,
  outerOffset: 5,
  animation1: css`
    animation: ${rotate360} 3s linear infinite;
  `,
  animation2: css`
    animation: ${rotate360} 3s linear infinite;
  `,
  animation3: css`
    animation: ${rotate360} 3s linear infinite;
  `
}

Spinner3.propTypes = {
  style: PropTypes.oneOfType([PropTypes.object, PropTypes.string]),
  size: PropTypes.number,
  innerOffset: PropTypes.number,
  outerOffset: PropTypes.number,
  spread: PropTypes.number,
  thickness: PropTypes.number,
  layer1: PropTypes.string,
  layer2: PropTypes.string,
  layer3: PropTypes.string,
  animation1: PropTypes.string,
  animation2: PropTypes.string,
  animation3: PropTypes.string
}
